from math import log
from scipy.stats import distributions
from bumps.names import *

USAGE = """
Usage: bumps check_entropy.py dist p1 p2 ...

where dist is one of the distributions in scipy.stats.distributions and
p1, p2, ... are the arguments for the distribution in the order that they
appear. For example, for the normal distribution, x ~ N(3, 0.8), use:

    bumps --fit=dream --entropy  --store=/tmp/T1 check_entropy.py norm 3 0.2
"""
if len(sys.argv) > 1:
    D_class = getattr(distributions, sys.argv[1])
    args = [float(v) for v in sys.argv[2:]]
    D = D_class(*args)
else:
    print(USAGE)
    sys.exit()

def D_nllf(x):
    return -D.logpdf(x)
M = PDF(D_nllf, x=0.9)
M.x.range(-inf, inf)

problem = FitProblem(M)

print("*** Expected entropy: %.4f"%(D.entropy()/log(2)))

